@@ -36,7 +36,11 @@ class InvenioThemeTUW:
             # thus, we just have to make sure that our blueprint is inserted before the
             # 'invenio_app_rdm' blueprints
             # note: the below code requires Flask 2.0.2+ and Python 3.7+
-            bps = {name: bp for name, bp in app.blueprints.items() if name != "invenio_theme_tuw"}
+            bps = {
+                name: bp
+                for name, bp in app.blueprints.items()
+                if name != "invenio_theme_tuw"
+            }
             app.blueprints = {"invenio_theme_tuw": blueprint, **bps}
 
     def init_config(self, app):
